To protect the system's integrity and the user's privacy, Android runs each app in a limited access sandbox.

If the app wants to use resources or information outside of its sandbox, the app has to explicitly request permission.

Depending on the type of permission the app requests, the system may grant the permission automatically, or the system
may ask the user to grant the permission.